Crate simple_uuid[][src]

This crate defines a uniform resource name namespace for UUIDs (Universally Unique IDentifier), also known as GUIDs (Globally Unique Identifier). A UUID is 128 bits long, and can guarantee uniqueness across space and time.

[dependencies]
simple-uuid = { version = "*", features = ["rand_num"] }
use simple_uuid::v4;
println!("{}", v4!());

Macros

v1mac_addr

UUID version-1

v3hash_md5

UUID version-3

v4rand_num

UUID version-4

v5hash_sha1

UUID version-5

Structs

ClockSeq

Used to avoid duplicates that could arise when the clock is set backwards in time.

Layout

The UUID format is 16 octets.

Node

Node field consists of an IEEE 802 MAC address, usually the host address

TimeStamp

Represented by Coordinated Universal Time (UTC) as a count of 100-ns intervals from the system-time.

UUID

Is a 128-bit number used to identify information in computer systems.

Enums

Variant

Variant is a type field determines the layout of the UUID.

Version

Version represents the type of UUID, and is in the most significant 4 bits of the Timestamp.

Constants

UTC_EPOCH

Is 100-ns ticks between UNIX and UTC epochs.