pub enum Variant {
NCS,
RFC,
MS,
FUT,
}Expand description
Variant is a type field determines the layout of the UUID.
Reserved, NCS backward compatibility.
The variant specified in rfc4122 document.
Reserved, Microsoft Corporation backward compatibility.
Reserved for future definition.
Formats the value using the given formatter. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.