Struct simple_uuid::UUID[][src]

pub struct UUID(_);

Is a 128-bit number used to identify information in computer systems.

Implementations

impl UUID[src]

pub fn new_v3(any: &str, namespace: UUID) -> Layout[src]

Generate new UUID by hashing, using MD5 algorithm.

pub fn new_v5(any: &str, namespace: UUID) -> Layout[src]

Generate a UUID by hashing, using SHA1 algorithm.

impl UUID[src]

pub fn new_v4() -> Layout[src]

New UUID from truly random numbers.

impl UUID[src]

pub fn new_v1() -> Option<Layout>[src]

New time-based UUID.

pub fn new_v2(d: Domain) -> Layout[src]

New DCE-security UUID.

On a POSIX system the id should be the users UID for the Person domain and the users GID for the Group.

pub fn from_utc(v: Version, utc: u64) -> Option<Layout>[src]

New UUID generated from a custom time.

pub fn from_mac(v: Version, mac: Node) -> Option<Layout>[src]

New UUID generated with a user defined MAC-address.

impl UUID[src]

pub const NAMESPACE_DNS: UUID[src]

UUID namespace for domain name system (DNS).

pub const NAMESPACE_OID: UUID[src]

UUID namespace for ISO object identifiers (OIDs).

pub const NAMESPACE_URL: UUID[src]

UUID namespace for uniform resource locators (URLs).

pub const NAMESPACE_X500: UUID[src]

UUID namespace for X.500 distinguished names (DNs).