Crate simple_uuid[−][src]
This crate defines a uniform resource name namespace for UUIDs (Universally Unique IDentifier), also known as GUIDs (Globally Unique Identifier). A UUID is 128 bits long, and can guarantee uniqueness across space and time.
[dependencies]
simple-uuid = { version = "*", features = ["rand_num"] }
use simple_uuid::v4; println!("{}", v4!());
Macros
| v1 | mac_addr
|
| v3 | hash_md5
|
| v4 | rand_num
|
| v5 | hash_sha1
|
Structs
| ClockSeq | Used to avoid duplicates that could arise when the clock is set backwards in time. |
| Layout | The UUID format is 16 octets. |
| Node | Node field consists of an IEEE 802 MAC address, usually the host address |
| TimeStamp | Represented by Coordinated Universal Time (UTC) as a count of 100-ns intervals from the system-time. |
| UUID | Is a 128-bit number used to identify information in computer systems. |
Enums
| Variant | Variant is a type field determines the layout of the UUID. |
| Version | Version represents the type of UUID, and is in the most significant 4 bits of the Timestamp. |
Constants
| UTC_EPOCH | Is 100-ns ticks between UNIX and UTC epochs. |