Crate simple_uuid[][src]

This crate defines a uniform resource name namespace for UUIDs (Universally Unique IDentifier), also known as GUIDs (Globally Unique Identifier). A UUID is 128 bits long, and can guarantee uniqueness across space and time.

[dependencies]
simple-uuid = { version = "*", features = ["random"] }
use simple_uuid::v4;
println!("{}", v4!());

Macros

v1

UUID version-1

v3

UUID version-3

v4

UUID version-4

v5

UUID version-5

Structs

ClockSeq

Used to avoid duplicates that could arise when the clock is set backwards in time.

Hash
Layout

The UUID format is 16 octets.

Node

The clock sequence is used to help avoid duplicates that could arise when the clock is set backwards in time or if the node ID changes.

Random
TimeStamp

Represented by Coordinated Universal Time (UTC) as a count of 100-ns intervals from the system-time.

UUID

Is a 128-bit number used to identify information in computer systems.

Enums

Algo
Variant

Variant is a type field determines the layout of the UUID.

Version

Version represents the type of UUID, and is in the most significant 4 bits of the Timestamp.

Constants

UTC_EPOCH

Is 100-ns ticks between UNIX and UTC epochs.